@@ -1,10 +1,11 @@
 from matplotlib import pyplot as plt
 import math
-from keras.callbacks import LambdaCallback, EarlyStopping, ModelCheckpoint, models
+from keras.callbacks import LambdaCallback, EarlyStopping, ModelCheckpoint
 import keras.backend as K
 import numpy as np
 import pandas as pd 
 from keras.callbacks import LambdaCallback
+import altair as alt
 class sanity_check:
     
   history = None
@@ -37,11 +38,11 @@ class sanity_check:
     steps_per_epochs = len(train_generator)
     
     for x in self.loss_record.keys():
-      K.clear_session()
+      #K.clear_session()
       print('learning_Rate : ',x)
       self.cur_rate = float(x)
       
-      mod = models.clone_model(self.model)
+      #mod = models.clone_model(self.model)
       
     
       K.set_value(self.model.optimizer.lr, x)
@@ -78,4 +79,15 @@ class sanity_check:
   def on_batch_end(self,batch,logs):
     lr = K.get_value(self.model.optimizer.lr)
     print(logs)
-    self.loss_record[self.cur_rate] += [logs['val_loss']]
\ No newline at end of file
+    self.loss_record[self.cur_rate] += [logs['val_loss']]
+  def plot_loss(self):
+    table = self.df
+
+
+    chart = alt.Chart(table).mark_line().encode(
+    x='epochs',
+    y='val_loss',
+    color='lr_rate',
+)
+    return chart
+
